#!/usr/bin/python2

import apt
import sys

try:
    cache = apt.Cache()
    pkg = cache[sys.argv[1]]
    if pkg.installed is not None:
        print (pkg.installed.version)
    else:
        print ("")
except:
    print ("")



#!/usr/bin/python2

import sys
import os
import commands

link = ' '.join(sys.argv[1:])
link = link.replace("\"", "")
link = "\"" + link + "\""

if os.path.exists("/usr/bin/gconftool-2"):
    browser = commands.getoutput("gconftool-2 --get /desktop/gnome/url-handlers/http/command")
    browser = browser.replace("\"%s\"", link)
    browser = browser.replace("%s", link)
else:
    browser = "firefox " + link

os.system(browser + " &")



#!/usr/bin/python2

import os
import gettext

def strip_split_and_recombine(comma_separated):
    word_list = comma_separated.split(",")
    out = ""
    for item in word_list:
        out += item.strip()
        out+=";"

    return out

def generate(domain, path, filename, prefix, name, comment, suffix, genericName=None, keywords=None):
    gettext.install(domain, path)
    desktopFile = open(filename, "w")

    desktopFile.writelines(prefix)

    desktopFile.writelines("Name=%s\n" % name)
    for directory in sorted(os.listdir(path)):
        if os.path.isdir(os.path.join(path, directory)):
            try:
                language = gettext.translation(domain, path, languages=[directory])
                language.install()
                if (_(name) != name):
                    desktopFile.writelines("Name[%s]=%s\n" % (directory, _(name)))
            except:
                pass

    desktopFile.writelines("Comment=%s\n" % comment)
    for directory in sorted(os.listdir(path)):
        if os.path.isdir(os.path.join(path, directory)):
            try:
                language = gettext.translation(domain, path, languages=[directory])
                language.install()
                if (_(comment) != comment):
                    desktopFile.writelines("Comment[%s]=%s\n" % (directory, _(comment)))
            except:
                pass

    if keywords is not None:
        formatted = strip_split_and_recombine(keywords)
        desktopFile.writelines("Keywords=%s\n" % formatted)
        for directory in sorted(os.listdir(path)):
            if os.path.isdir(os.path.join(path, directory)):
                try:
                    language = gettext.translation(domain, path, languages=[directory])
                    language.install()
                    if (_(keywords) != keywords):
                        translated = strip_split_and_recombine(_(keywords))
                        desktopFile.writelines("Keywords[%s]=%s\n" % (directory, translated))
                except:
                    pass

    if genericName is not None:
        desktopFile.writelines("GenericName=%s\n" % genericName)
        for directory in sorted(os.listdir(path)):
            if os.path.isdir(os.path.join(path, directory)):
                try:
                    language = gettext.translation(domain, path, languages=[directory])
                    language.install()
                    if (_(genericName) != genericName):
                        desktopFile.writelines("GenericName[%s]=%s\n" % (directory, _(genericName)))
                except:
                    pass

    desktopFile.writelines(suffix)
    os.environ['LANG'] = "en_US.UTF-8"
    gettext.install(domain, path)



#!/usr/bin/python2

import gi
gi.require_version('Gtk', '3.0')
from gi.repository import Gtk

try:
    import sys
    import string
    import os
    import commands
    import threading
    import tempfile
    import gettext

except Exception, detail:
    print detail
    sys.exit(1)

from subprocess import Popen

# i18n
gettext.install("mint-common", "/usr/share/linuxmint/locale")


class RemoveExecuter(threading.Thread):

    def __init__(self, packages):
        threading.Thread.__init__(self)
        self.packages = packages

    def run(self):
        cmd = ["sudo", "/usr/sbin/synaptic", "--hide-main-window",
               "--non-interactive"]
        cmd.append("--progress-str")
        cmd.append("\"" + _("Please wait, this can take some time") + "\"")
        cmd.append("--finish-str")
        cmd.append("\"" + _("Application removed successfully") + "\"")
        f = tempfile.NamedTemporaryFile()
        strbuffer = ""
        for pkg in self.packages:
            strbuffer = strbuffer + "%s\tdeinstall\n" % pkg
        f.write(strbuffer)
        f.flush()
        cmd.append("--set-selections-file")
        cmd.append("%s" % f.name)
        comnd = Popen(cmd)
        returnCode = comnd.wait()
        f.close()
        sys.exit(0)

class MintRemoveWindow:

    def __init__(self, desktopFile):
        self.desktopFile = desktopFile
        (status, output) = commands.getstatusoutput("dpkg -S " + self.desktopFile)
        package = output[:output.find(":")].split(",")[0]
        if status != 0:
            warnDlg = Gtk.MessageDialog(None, 0, Gtk.MessageType.WARNING, Gtk.ButtonsType.YES_NO, _("This menu item is not associated to any package. Do you want to remove it from the menu anyway?"))
            warnDlg.vbox.set_spacing(10)
            response = warnDlg.run()
            if response == Gtk.ResponseType.YES:
                print "removing '%s'" % self.desktopFile
                os.system("rm -f '%s'" % self.desktopFile)
                os.system("rm -f '%s.desktop'" % self.desktopFile)
            warnDlg.destroy()
            sys.exit(0)

        warnDlg = Gtk.MessageDialog(None, 0, Gtk.MessageType.WARNING, Gtk.ButtonsType.OK_CANCEL, _("The following packages will be removed:"))
        warnDlg.vbox.set_spacing(10)

        treeview = Gtk.TreeView()
        column1 = Gtk.TreeViewColumn(_("Packages to be removed"))
        renderer = Gtk.CellRendererText()
        column1.pack_start(renderer, False)
        column1.add_attribute(renderer, "text", 0)
        treeview.append_column(column1)

        packages = []
        model = Gtk.ListStore(str)
        dependenciesString = commands.getoutput("apt-get -s -q remove " + package + " | grep Remv")
        dependencies = string.split(dependenciesString, "\n")
        for dependency in dependencies:
            dependency = dependency.replace("Remv ", "")
            model.append([dependency])
            packages.append(dependency.split()[0])
        treeview.set_model(model)
        treeview.show()

        scrolledwindow = Gtk.ScrolledWindow()
        scrolledwindow.set_shadow_type(Gtk.ShadowType.ETCHED_OUT)
        scrolledwindow.set_size_request(150, 150)
        scrolledwindow.add(treeview)
        scrolledwindow.show()

        warnDlg.get_content_area().add(scrolledwindow)

        response = warnDlg.run()
        if response == Gtk.ResponseType.OK:
            executer = RemoveExecuter(packages)
            executer.start()
        elif response == Gtk.ResponseType.CANCEL:
            sys.exit(0)
        warnDlg.destroy()

if __name__ == "__main__":

    # Exit if the given path does not exist
    if len(sys.argv) < 2 or not os.path.exists(sys.argv[1]):
        sys.exit(1)

    mainwin = MintRemoveWindow(sys.argv[1])
    Gtk.main()



#!/usr/bin/python2

import os
import gettext
import sys
sys.path.append('/usr/lib/linuxmint/common')
import additionalfiles

DOMAIN = "mint-common"
PATH = "/usr/share/linuxmint/locale"

prefix = "[Nemo Action]\n"

suffix = """Exec=thunderbird -compose to=,\"attachment='%F'\"
Icon-Name=mail-attachment
Selection=NotNone
Extensions=nodirs;
Dependencies=thunderbird;
Separator=,
"""

os.environ['LANG'] = "en_US.UTF-8"
gettext.install(DOMAIN, PATH)
additionalfiles.generate(DOMAIN, PATH, "usr/share/nemo/actions/mint-artwork-cinnamon-thunderbird.nemo_action", prefix, _("Send by Email"), _("Send as email attachment"), suffix)



#!/usr/bin/python2

import os
import gettext

gettext.install("mint-common", "/usr/share/linuxmint/locale")

if os.path.exists("/usr/bin/gksu"):
    launcher = "gksu  --message \"<b>" + _("Please enter your password") + "</b>\""
elif os.path.exists("/usr/bin/kdesudo"):
    launcher = "kdesudo -i /usr/share/linuxmint/logo.png -d --comment \"<b>" + _("Please enter your password") + "</b>\""

print (launcher)



#!/usr/bin/python2

import os
import gettext

DOMAIN = "mint-common"
PATH = "/usr/share/linuxmint/locale"


def generate(filename, prefix, name, comment, suffix):
    print "HERE"
    os.environ['LANG'] = "en_US.UTF-8"
    gettext.install(DOMAIN, PATH)
    desktopFile = open(filename, "w")

    desktopFile.writelines(prefix)

    desktopFile.writelines("Name=%s\n" % name)
    print ("Name=%s\n" % name)
    for directory in sorted(os.listdir(PATH)):
        if os.path.isdir(os.path.join(PATH, directory)):
            try:
                language = gettext.translation(DOMAIN, PATH, languages=[directory])
                language.install()
                if (_(name) != name):
                    desktopFile.writelines("Name[%s]=%s\n" % (directory, _(name)))
                    print ("Name[%s]=%s\n" % (directory, _(name)))
            except:
                pass

    desktopFile.writelines("Comment=%s\n" % comment)
    for directory in sorted(os.listdir(PATH)):
        if os.path.isdir(os.path.join(PATH, directory)):
            try:
                language = gettext.translation(DOMAIN, PATH, languages=[directory])
                language.install()
                if (_(comment) != comment):
                    desktopFile.writelines("Comment[%s]=%s\n" % (directory, _(comment)))
            except:
                pass

    desktopFile.writelines(suffix)
